package Requests;

import commandSystem.Direction;

public abstract class Request {
	
	protected RequestType type;
	protected int wantedFloor;
	protected int sourceFloor;
	protected Direction direction;
	protected int reachedFloor;
	
	public Request(RequestType type) {
		this.type = type;
		this.reachedFloor = -1;
		this.wantedFloor = -1;
		this.sourceFloor = -1;
		this.direction = Direction.NONE;
	}
	
	/**
	 * 
	 * @return the direction of the request, unconcerned extending classes return NONE.
	 */
	public Direction getDirection() {
		return direction;
	}

	/**
	 * 
	 * @return the wished floor, unconcerned extending classes return -1.
	 */
	public int getWantedFloor() {
		return wantedFloor;
	}

	/**
	 * 
	 * @return the floor it was called from, unconcerned extending classes return -1.
	 */
	public int getIncomingCallFloor() {
		return sourceFloor;
	}

	/**
	 * 
	 * @return the RequestType of the request.
	 */
	public RequestType getType() {
		return type;
	}
	
	/**
	 * 
	 * @return the floor the elevator just reached, unconcerned extending classes return -1.
	 */
	public int getReachedFloor() {
		return reachedFloor;
	}
}
